Skip to contents

Extracts the top predicted species from a prediction result.

Usage

get_top_species(prediction)

Arguments

prediction

A single prediction result from predict_species.

Value

A character string with the top predicted class, or "blank" if no predictions.